enum UNIT {
    //% block="温度(℃)"
    getTemperature,
    //% block="湿度(%RH)"
    getHumidity,
    //% block="海拔(m)"
    getAltitude,
    //% block="气压(Pa)"
    getPressure
}

enum AIR {
    //% block="CO2(ppm)"
    getCO2PPM,
    //% block="TVOC(ppb)"
    getTVOCPPB
}
}

enum BME280_ADDR {
    //% block="0x76"
    0x76,
    //% block="0x77"
    0x77
}

enum CCS811_ADDR {
    //% block="0x5A"
    0x5A,
    //% block="0x5B"
    0x5B
}

enum DELAY {
    //% block="250ms"
    eCycle_250ms,
    //% block="1s"
    eCycle_1s,
    //% block="10s"
    eCycle_10s,
    //% block="60s"
    eCycle_60s
    //% block="空闲"
    eClosed
}



//% color="#4169E1" iconWidth=50 iconHeight=40
namespace Environment{
    //% block="BME280初始化：I2C地址[BME280_ADDR]，CCS811初始化：获取数据时间[DELAY]基数[NUMBER]I2C地址0x5A" blockType="command" 
    //% BME280_ADDR.shadow="dropdown"   BME280_ADDR.options="BME280_ADDR"
	//% DELAY.shadow="dropdown" DELAY.options="DELAY"
    //% NUMBER.shadow="number" NUMBER.defl="17531"
    export function Init(parameter: any, block: any) {
        let bme280_addr = parameter.BME280_ADDR.code;
		let del = parameter.DELAY.code;
        let num = parameter.NUMBER.code;
 		Generator.addInclude("DFRobot_BME280", `#include "DFRobot_BME280.h"`);
		Generator.addInclude("DFRobot_CCS811Init", `#include "DFRobot_CCS811_I2C.h"`); 
        Generator.addObject(`object`, `DFRobot_BME280_IIC`, `bme280;`);    
        Generator.addSetup(`DFRobot_BME280InitReady`,`bme280.begin(${bme280_addr});`);      
        Generator.addObject(`DFRobot_CCS811Init`,`DFRobot_CCS811_I2C`,`ccs811;`);		
		Generator.addSetup(`DFRobot_CCS811InitReady`, `while(ccs811.begin() != 0);`);
        Generator.addSetup(`DFRobot_CCS811InitReady1`, `ccs811.setMeasCycle(ccs811.${del});`);
        Generator.addSetup(`DFRobot_CCS811InitReady4`, `ccs811.writeBaseLine(${num});`);
    }
	
	
    //% block="CCS811空气质量是否有数据?" blockType="boolean"  
    export function DFRobot_CCS811InitReady(parameter: any, block: any) { 
        Generator.addCode(`ccs811.checkDataReady()`);   
    }
	
	
    //% block="读取CCS811空气质量[AIR]的值 " blockType="reporter" 
    //% AIR.shadow="dropdown" AIR.options="AIR"
    export function getCCS811Date(parameter: any, block: any) { 
        let air=parameter.AIR.code;       
        Generator.addCode(`ccs811.${air}()`);   
    }
	
	
    //% block="获取CCS811基数" blockType="reporter"
    export function getBaseLine(parameter: any, block: any) { 
        Generator.addCode(`ccs811.readBaseLine()`);
   
   } 
   

    //% block="读取BME280[UNIT]的值" blockType="reporter"
    //% UNIT.shadow="dropdown"   UNIT.options="UNIT"
    export function getBME280Date(parameter: any, block: any) { 
        let unit = parameter.UNIT.code;
        Generator.addCode(`bme280.${unit}()`);
   
   } 

   
   
}