enum UNIT {
    //% block="温度(℃)"
    temp_c,
    //% block="湿度(%RH)"
    humidity,
    //% block="海拔(m)"
    cal_altitudu,
    //% block="气压(Pa)"
    press_pa
}

enum AIR {
    //% block="CO2(ppm)"
    co2_ppm,
    //% block="TVOC(ppb)"
    tvoc_ppb
}

enum BME280_ADDR {
    //% block="0x76"
    0x76,
    //% block="0x77"
    0x77
}

enum CCS811_ADDR {
    //% block="0x5A"
    0x5A,
    //% block="0x5B"
    0x5B
}

enum DELAY {
    //% block="250ms"
    eCycle_250ms,
    //% block="1s"
    eCycle_1s,
    //% block="10s"
    eCycle_10s,
    //% block="60s"
    eCycle_60s
    //% block="空闲"
    eClosed
}



//% color="#4169E1" iconWidth=50 iconHeight=40
namespace Environment{
    //% block="BME280初始化：I2C地址[BME280_ADDR]，CCS811初始化：I2C地址[CCS811_ADDR]获取数据时间[DELAY]基数[NUMBER]" blockType="command" 
    //% BME280_ADDR.shadow="dropdown"   BME280_ADDR.options="BME280_ADDR"
	//% CCS811_ADDR.shadow="dropdown"   CCS811_ADDR.options="CCS811_ADDR"
	//% DELAY.shadow="dropdown" DELAY.options="DELAY"
    //% NUMBER.shadow="number" NUMBER.defl="17531"
    export function Init(parameter: any, block: any) {
        let bme280_addr = parameter.BME280_ADDR.code;
		let ccs811_addr = parameter.CCS811_ADDR.code;
		let del = parameter.DELAY.code;
		let del = parameter.DELAY.code;
        let num = parameter.NUMBER.code;
 		Generator.addImport("from pinpong.libs.dfrobot_bme280 import BME280");
		Generator.addImport("from pinpong.libs.dfrobot_ccs811 import CCS811, CCS811_Ecycle");
		Generator.addImport("from pinpong.board import Board");
		Generator.addCode(`Board().begin()`);
		Generator.addCode(`p_bme280 = BME280(${bme280_addr})`); 
		Generator.addCode(`p_ccs811 = CCS811(${ccs811_addr})`); 
		Generator.addCode(`p_ccs811.set_meas_cycle(CCS811_Ecycle.${del})`); 
		Generator.addCode(`p_ccs811.write_base_line(${num})`); 
    }
	
	
    //% block="CCS811空气质量是否有数据?" blockType="boolean"  
    export function DFRobot_CCS811InitReady(parameter: any, block: any) { 
        Generator.addCode(`p_ccs811.check_data_ready()`);   
    }
	
	
    //% block="读取CCS811空气质量[AIR]的值 " blockType="reporter" 
    //% AIR.shadow="dropdown" AIR.options="AIR"
    export function getCCS811Date(parameter: any, block: any) { 
        let air=parameter.AIR.code;       
        Generator.addCode(`p_ccs811.${air}()`);   
    }
	
	
	
    //% block="获取CCS811基数" blockType="reporter"
    export function getBaseLine(parameter: any, block: any) { 
        Generator.addCode(`p_ccs811.read_baseline()`);
   
   } 

    //% block="读取BME280[UNIT]的值" blockType="reporter"
    //% UNIT.shadow="dropdown"   UNIT.options="UNIT"
    export function getBME280Date(parameter: any, block: any) { 
        let unit = parameter.UNIT.code;
        Generator.addCode(`p_bme280.${unit}()`);
   
   } 
	
   
}